"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const express = require("express");
const io = require("socket.io");
const compression = require("compression");
const logger = require("morgan");
const bodyParser = require("body-parser");
const http = require("http");
const staticFile = require("connect-static-file");
const basicutil_1 = require("basicutil");
class ApiConfiguration {
    constructor(expressInstance, api, packageJSON) {
        this.packageJSON = packageJSON;
        this.api = api;
        this.express = expressInstance;
        this.configureMiddleware();
        this.configureRoutes();
        this.router = express.Router();
    }
    run() {
        this.server = http.createServer(this.express);
        this.io = io(this.server);
        this.api.setIo(this.io);
        this.server.listen(basicutil_1.Util.getInstance().normalizePort(this.packageJSON.env.port || 3000));
        this.api.afterListen();
        this.server.on('error', () => this.onError);
        this.server.on('listening', () => this.onListening());
    }
    configureMiddleware() {
        if (this.packageJSON.env.js.compression) {
            console.log('Using Compression');
            this.express.use('*.js', compression({ threshold: 0 }));
        }
        const manifestFile = 'manifest.json';
        this.express.use('/' + manifestFile, staticFile(path.resolve(manifestFile), {}));
        this.packageJSON.arrayPath.forEach(pathString => {
            this.express.use(express.static(path.resolve(pathString)));
        });
        this.express.use(logger('dev'));
        this.express.use(bodyParser.json());
        this.express.use(bodyParser.urlencoded({ extended: true }));
    }
    configureRoutes() {
        this.express.use('/', this.api.getRouter());
    }
    onError(error) {
        if (error.syscall !== 'listen') {
            throw error;
        }
        let bind = (typeof this.packageJSON.env.port === 'string') ? 'Pipe ' + this.packageJSON.env.port : 'Port ' + this.packageJSON.env.port;
        switch (error.code) {
            case 'EACCES':
                console.error(`${bind} requires elevated privileges`);
                process.exit(1);
                break;
            case 'EADDRINUSE':
                console.error(`${bind} is already in use`);
                process.exit(1);
                break;
            default:
                throw error;
        }
    }
    onListening() {
        let address = this.server.address();
        let bind = (typeof address === 'string') ? `pipe ${address}` : `port ${address.port}`;
        console.log(`Listening on ${bind}`);
    }
}
exports.ApiConfiguration = ApiConfiguration;
//# sourceMappingURL=apiConfiguration.js.map