"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const electron_1 = require("electron");
const path = require("path");
class Electron {
    constructor(touch, touchSimulate, frame, kiosk, node, width, height, fullscreen, useContentSize, autoHideMenuBar, title, consoleVar, url, zoom, overlayScrollbars, development, icon) {
        if (electron_1.app !== undefined) {
            this.touch = touch === '1' ? 1 : 0;
            this.touchSimulate = touchSimulate === '1' ? 1 : 0;
            this.frame = frame === '1' ? 1 : 0;
            this.kiosk = kiosk === '1' ? 1 : 0;
            this.node = node === '1' ? 1 : 0;
            this.width = parseInt(width || 1920, 10);
            this.height = parseInt(height || 1080, 10);
            this.fullscreen = fullscreen === '1' ? 1 : 0;
            this.useContentSize = useContentSize === '1' ? 1 : 0;
            this.autoHideMenuBar = autoHideMenuBar === '1' ? 1 : 0;
            this.title = title;
            this.console = consoleVar === '1' ? 1 : 0;
            this.url = url;
            this.zoom = parseFloat(zoom || 1.0);
            this.overlayScrollbars = overlayScrollbars === '1' ? 1 : 0;
            this.development = development;
            this.icon = icon;
            if (this.touch) {
                electron_1.app.commandLine.appendSwitch('--touch-devices');
            }
            if (this.touchSimulate) {
                electron_1.app.commandLine.appendSwitch('--simulate-touch-screen-with-mouse');
            }
            if (this.development === 'development') {
                console.log('Running in development mode');
                this.height = 600;
                this.width = 800;
                this.kiosk = 0;
                this.console = 1;
                this.frame = 1;
            }
            this.init();
        }
    }
    createWindow() {
        let appIcon = electron_1.nativeImage.createFromPath(path.resolve(this.icon));
        this.mainWindow = new electron_1.BrowserWindow({
            fullscreen: this.fullscreen,
            frame: !!(this.frame),
            useContentSize: this.useContentSize,
            autoHideMenuBar: this.autoHideMenuBar,
            icon: appIcon,
            width: this.width,
            height: this.height,
            title: this.title,
            kiosk: !!(this.kiosk),
            webPreferences: {
                nodeIntegration: !!(this.node),
                zoomFactor: this.zoom
            }
        });
        this.mainWindow.loadURL(this.url);
        if (this.console) {
            this.mainWindow.webContents.openDevTools();
        }
        this.mainWindow.on('closed', () => {
            this.mainWindow = null;
        });
    }
    quit() {
        if (process.platform !== 'darwin') {
            electron_1.app.quit();
        }
    }
    activate() {
        if (this.mainWindow === null) {
            this.createWindow();
        }
    }
    init() {
        let _self = this;
        electron_1.app.on('ready', () => { _self.createWindow(); });
        electron_1.app.on('window-all-closed', () => { _self.quit(); });
        electron_1.app.on('activate', () => { _self.activate(); });
    }
}
exports.Electron = Electron;
//# sourceMappingURL=electron.js.map